import { Context } from "./signal";
import { StateNode, SetStateFunction, Wrapped } from "./state";
declare type SuspenseState = "running" | "suspended" | "fallback";
declare type SuspenseContextType = {
    increment?: () => void;
    decrement?: () => void;
    state?: () => SuspenseState;
    initializing?: boolean;
};
declare type SuspenseConfig = {
    timeoutMs: number;
};
export declare const SuspenseContext: Context<SuspenseContextType> & {
    transition?: {
        timeoutMs: number;
        increment(): void;
        decrement(): void;
    };
    active?(): boolean;
    increment?(): void;
    decrement?(): void;
};
export declare function createResource<T>(): [() => T | undefined, (v: T | undefined) => void];
export declare function createResourceState<T extends StateNode>(state: T | Wrapped<T>): [Wrapped<T>, SetStateFunction<T>];
interface ComponentType<T> {
    (props: T): any;
}
export declare function lazy<T extends ComponentType<any>>(fn: () => Promise<{
    default: T;
}>): T;
export declare function load<T>(fn: () => Promise<T> | undefined, resolve: (v: T | undefined) => void, reject?: (e: any, failedAttempts: number) => boolean | void): [() => boolean, () => void];
export declare function useTransition(config: SuspenseConfig): [() => boolean, (fn: () => any) => void];
export declare function awaitSuspense<T>(fn: () => T): () => T;
export {};
